# Changes

## 2021-05-24

- Add select_iter() to be able to select() without fetch_all()
- Add double() function to use multiple cursors in a single ExecutionContext


## 2021-05-19

- Add MemorySource to fetch database into RAM before querying


## 2018-03-03

- Auto expanduser path.


## 2018-01-24

- First release to PyPI


## 2015-09-09

- Reorganise project structure

